# Before After

Before After is a Dash component library.

Get started with:
1. Install Dash and its dependencies: https://dash.plotly.com/installation
2. Run `python usage.py`
3. Visit http://localhost:8050 in your web browser


This is a responsive and trouchscreen friendly before & after image slider.

Based on the React component https://github.com/sneas/img-comparison-slider

This is a pre-release trial - please don't use this in a production environment yet.